const getSite = () => {
  const host = window.location.host
  const [, , portal] = host.match(/infojobs(\w*)\.(\w*)/) || [
    'infojobs',
    '',
    'net'
  ]

  return portal === 'it' ? 'infojobs.it' : 'infojobs.net'
}
const optionsFactory = async ({trackingOptions, visitorId}) => {
  const options = {
    ...trackingOptions,
    traits: {
      ...trackingOptions.traits,
      anonymousId: window.analytics.user().anonymousId(),
      userId: window.analytics.user().id()
    },
    integrations: {
      ...trackingOptions.integrations,
      'Adobe Analytics': {
        marketingCloudVisitorId: visitorId
      }
    }
  }

  return options
}

const propertiesFactory = trackingProperties => {
  return {
    ...trackingProperties,
    site: getSite()
  }
}

export default ({visitorId}) => ({
  identify: (...args) => {
    return new Promise((resolve, reject) => {
      window.analytics.identify(...args)
      resolve()
    })
  },
  reset: (...args) => {
    return new Promise((resolve, reject) => {
      window.analytics.reset(...args)
      resolve()
    })
  },
  track: (...args) => {
    return new Promise((resolve, reject) => {
      window.analytics.ready(async function() {
        const [event, properties = {}, trackingOptions = {}, fn] = args

        window.analytics.track(
          event,
          propertiesFactory(properties),
          await optionsFactory({
            trackingOptions,
            visitorId
          }),
          fn
        )
        return resolve()
      })
    })
  }
})
