import jsCookie from 'js-cookie'
import {parse} from 'qs'
const NAV_ORIGEN = 'navOrigen'

const ALLOWED_NAV_ORIGINS = [
  NAV_ORIGEN,
  'applicationOrigin',
  'caCmpInt',
  'caCmpExt',
  'caInscInt',
  'caInscExt',
  'emCmpInt',
  'emCmpExt',
  'emAltaInt',
  'Ad',
  'purchaseOrigin'
]

const SUFIXES_TTL = {
  '': 1,
  Mes: 30,
  Sesion: undefined
}

const extractCookieDomain = function(hostname) {
  let parts = hostname.split('.')
  return '.' + parts[parts.length - 2] + '.' + parts[parts.length - 1]
}

const saveCookies = function(key, value, cookieDomain) {
  Object.keys(SUFIXES_TTL).forEach(SUFIX => {
    jsCookie.set(`${key}${SUFIX}`, value, {
      expires: SUFIXES_TTL[SUFIX],
      domain: cookieDomain
    })
  })
}

const loadCookies = function(
  hostname = window.location.hostname,
  search = window.location.search
) {
  let navOrigins = parse(search, {ignoreQueryPrefix: true}).navOrigen
  if (!navOrigins) {
    return
  }

  if (typeof navOrigins === 'string') {
    navOrigins = [navOrigins]
  }
  let cookieDomain = extractCookieDomain(hostname)
  navOrigins.forEach(navOrigen => {
    const sections = navOrigen.split('|')
    let key, value
    if (sections.length === 1) {
      key = NAV_ORIGEN
      value = sections[0]
      saveCookies(key, value, cookieDomain)
    } else {
      key = sections[0]
      if (ALLOWED_NAV_ORIGINS.some(section => section === key)) {
        value = sections[1]
        saveCookies(key, value, cookieDomain)
      }
    }
  })
}

export default loadCookies
