import {expect} from 'chai'
import sinon from 'sinon'
import listenToClicksToTrack from '../../src/analytics/clickListener'

describe('#clickListener', () => {
  const FAKE_EVENT = 'myFakeEvent'
  const FAKE_ID = 'myFakeId'
  const FAKE_PROPS = '{&quot;section&quot;:&quot;candidate&quot;}'
  let trackStub
  let buttonEl

  before(() => {
    window.rubik = window.rubik || {}
    window.rubik.analytics = window.rubik.analytics || {track: function() {}}
    trackStub = sinon.stub(window.rubik.analytics, 'track')
  })

  after(() => {
    trackStub.restore()
  })

  describe('when event and properties are set', () => {
    before(() => {
      const fixture = `
    <button
      id="${FAKE_ID}"
      data-track="${FAKE_EVENT}"
      data-track-properties="${FAKE_PROPS}"
      >
        Click me!
    </button>
    `
      document.body.insertAdjacentHTML('afterbegin', fixture)
      listenToClicksToTrack()
      buttonEl = document.getElementById(FAKE_ID)
    })

    after(() => {
      buttonEl.parentNode.removeChild(buttonEl)
    })

    it('should track the right event with its props', () => {
      buttonEl.click()
      expect(trackStub.firstCall.args[0]).to.equal(FAKE_EVENT)
      expect(trackStub.firstCall.args[1]).to.deep.equal({
        section: 'candidate'
      })
    })
  })

  describe('when event is set without properties', () => {
    before(() => {
      const fixture = `
    <button
      id="${FAKE_ID}"
      data-track="${FAKE_EVENT}"
      >
        Click me!
    </button>
    `
      document.body.insertAdjacentHTML('afterbegin', fixture)
      listenToClicksToTrack()
      buttonEl = document.getElementById(FAKE_ID)
    })

    after(() => {
      buttonEl.parentNode.removeChild(buttonEl)
    })

    it('should track the right event with no props', () => {
      buttonEl.click()
      expect(trackStub.getCall(1).args[0]).to.equal(FAKE_EVENT)
      expect(trackStub.getCall(1).args[1]).to.be.empty
    })
  })

  describe('when no event is set ', () => {
    before(() => {
      const fixture = `
    <button
      id="${FAKE_ID}"
      >
        Click me!
    </button>
    `
      document.body.insertAdjacentHTML('afterbegin', fixture)
      listenToClicksToTrack()
      buttonEl = document.getElementById(FAKE_ID)
    })

    after(() => {
      buttonEl.parentNode.removeChild(buttonEl)
    })

    it('should not call the track function', () => {
      buttonEl.click()
      sinon.assert.callCount(trackStub, 2)
    })
  })
})
