import sinon from 'sinon'
import {expect} from 'chai'
import idSync from '../src/analytics/idSync'
const axios = require('axios')

describe('#idSync', () => {
  let axiosStub
  beforeEach(() => {
    axiosStub = sinon.stub(axios, 'get').resolves(true)
  })

  afterEach(() => {
    axiosStub.restore()
  })

  describe('when adobe id exist', done => {
    const adobeVisitorId = 'fakeAdobeId'

    describe('when ij id exist', done => {
      const infojobsVisitorId = 'fakeInfojobsId'

      it('should sent a request with the adobe id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            expect(axiosStub.firstCall.args[1].params).to.deep.equal({
              d_cid_ic: 'XID%01fakeAdobeId',
              d_mid: 'fakeInfojobsId',
              d_orgid: '05FF6243578784B37F000101@AdobeOrg',
              d_rtbd: 'json',
              d_ver: 2,
              dcs_region: 6
            })
            done()
          })
          .catch(done)
      })
      it('should sent a request with the ij id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            expect(axiosStub.getCall(1).args[1].params).to.deep.equal({
              d_cid_ic: 'XID%01fakeInfojobsId',
              d_mid: 'fakeInfojobsId',
              d_orgid: '05FF6243578784B37F000101@AdobeOrg',
              d_rtbd: 'json',
              d_ver: 2,
              dcs_region: 6
            })
            done()
          })
          .catch(done)
      })
    })
    describe('when ij id does not exist', done => {
      const infojobsVisitorId = ''

      it('should sent a request with the adobe id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            expect(axiosStub.getCall(0).args[1].params).to.deep.equal({
              d_cid_ic: 'XID%01fakeAdobeId',
              d_mid: 'fakeAdobeId',
              d_orgid: '05FF6243578784B37F000101@AdobeOrg',
              d_rtbd: 'json',
              d_ver: 2,
              dcs_region: 6
            })
            done()
          })
          .catch(done)
      })
      it('should not sent a request with the ij id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            sinon.assert.callCount(axiosStub, 1)
            done()
          })
          .catch(done)
      })
    })
  })

  describe('whene adobe id does not exist', done => {
    const adobeVisitorId = ''

    describe('when ij id exist', done => {
      const infojobsVisitorId = 'fakeIjId'

      it('should not sent a request with the adobe id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            expect(axiosStub.getCall(0).args[1].params).to.deep.equal({
              d_cid_ic: 'XID%01fakeIjId',
              d_mid: 'fakeIjId',
              d_orgid: '05FF6243578784B37F000101@AdobeOrg',
              d_rtbd: 'json',
              d_ver: 2,
              dcs_region: 6
            })
            done()
          })
          .catch(done)
      })
      it('should sent a request with the ij id', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            sinon.assert.callCount(axiosStub, 1)
            done()
          })
          .catch(done)
      })
    })
    describe('when ij id does not exist', done => {
      const infojobsVisitorId = ''

      it('should not sent any request', done => {
        idSync({adobeVisitorId, infojobsVisitorId})
          .then(() => {
            sinon.assert.callCount(axiosStub, 0)
            done()
          })
          .catch(done)
      })
    })
  })
})
