import {expect} from 'chai'
import sinon from 'sinon'
import {loader} from '../src-umd/index'
const visitorIdHandler = require('../src/analytics/visitorIdHandler')

describe('#loader', () => {
  let rubikLoadedSpy
  let visitorIdStub
  beforeEach(() => {
    rubikLoadedSpy = sinon.spy()
    document.addEventListener('rubik:loaded', rubikLoadedSpy)
    visitorIdStub = sinon
      .stub(visitorIdHandler, 'default')
      .resolves({infojobsVisitorId: 'fakeIjId', adobeVisitorId: 'fakeAdobeId'})
  })

  afterEach(() => {
    visitorIdStub.reset()
    document.removeEventListener('rubik:loaded', rubikLoadedSpy)
  })

  describe('when the rubik:loaded event is fired', () => {
    it('did initialize the analytics module', done => {
      loader()
        .then(() => {
          expect(window.rubik.analytics).to.exist
          expect(rubikLoadedSpy.callCount).to.equal(1)
          done()
        })
        .catch(done)
    })
  })
})
