import {expect} from 'chai'
import sinon from 'sinon'
import segmentWrapper from '../src/analytics/segmentWrapper'

describe('#segmentWrapper', () => {
  const trackArgs = [
    'fakeEvent',
    {fakePropKey: 'fakePropValue'},
    {
      fakeOptionKey: 'fakeOptionValue',
      traits: {fakeTraitKey: 'fakeTraitValue'},
      integrations: {fakeIntegrationKey: 'fakeIntegrationValue'}
    }
  ]

  const visitorId = 'fakeVisitorId'

  beforeEach(() => {
    window.Visitor = {}
    window.Visitor.getInstance = sinon.stub().returns({
      getMarketingCloudVisitorID: sinon.stub().returns('fakeCloudId')
    })

    window.analytics = {
      ready: function(cb) {
        return new Promise((resolve, reject) => {
          resolve(cb())
        })
      },
      user: () => ({
        anonymousId: () => 'fakeAnonymousId',
        id: () => 'fakeId'
      }),
      track: sinon.stub()
    }
  })

  afterEach(() => {
    delete window.Visitor
    delete window.analytics
  })

  describe('when the track event is called', () => {
    it('should set the visitor id as adobe analytics trait', done => {
      segmentWrapper({visitorId})
        .track(...trackArgs)
        .then(() => {
          expect(
            window.analytics.track.firstCall.args[2].integrations[
              'Adobe Analytics'
            ].marketingCloudVisitorId
          ).to.equal('fakeVisitorId')
          done()
        })
        .catch(done)
    })

    it('should set the right site prop', done => {
      segmentWrapper({visitorId})
        .track(...trackArgs)
        .then(() => {
          expect(window.analytics.track.firstCall.args[1].site).to.equal(
            'infojobs.net'
          )
          done()
        })
        .catch(done)
    })

    it('should add anonymousId as options trait', done => {
      segmentWrapper({visitorId})
        .track(...trackArgs)
        .then(() => {
          expect(
            window.analytics.track.firstCall.args[2].traits.anonymousId
          ).to.equal('fakeAnonymousId')
          done()
        })
        .catch(done)
    })
  })
})
